//package com.prolog.cs.biz.outbound.controller;
//
//import com.alibaba.fastjson.JSON;
//import com.netflix.hystrix.strategy.concurrency.HystrixRequestContext;
//import com.prolog.framework.authority.util.HystrixVarUtil;
//import org.junit.After;
//import org.junit.Before;
//import org.junit.Test;
//import org.junit.runner.RunWith;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.boot.test.context.SpringBootTest;
//import org.springframework.test.context.junit4.SpringRunner;
//import org.springframework.test.context.web.WebAppConfiguration;
//
//import java.util.ArrayList;
//import java.util.List;
//
//@RunWith(SpringRunner.class)
//@SpringBootTest
//@WebAppConfiguration
//public class InnerCheckControllerTest {
//
//    @Autowired
//    private InnerCheckController InnerCheckController;
//
//    @Before
//    public void before() throws Exception {
//        HystrixRequestContext context = HystrixRequestContext.initializeContext();
//        HystrixVarUtil.setUserKey("kzywms-admin");
//    }
//
//    @After
//    public void after() throws Exception {
//    }
//
//    @Test//
//    public void testGetCheckInfoFromContainerId() throws Exception {
//        System.out.println(JSON.toJSONString(InnerCheckController.getCheckInfoFromContainerId(
//                //"186","FH2-01")));
//                "30002773","FH3-QX")));
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.checkItem()));
//    public void testCheckItem() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.checkItemByNum()));
//    public void testCheckItemByNum() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.saveInnerCheckDetails()));
//    public void testSaveInnerCheckDetails() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.containerCheckConfirm()));
//    public void testContainerCheckConfirm() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.addLcl()));
//    public void testAddLcl() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.printLcl()));
//    public void testPrintLcl() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.printLclDetail()));
//    public void testPrintLclDetail() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.makeCheckRed()));
//    public void testMakeCheckRed() throws Exception {
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.queryLcl()));
//    public void testQueryLcl() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.lclAdjust()));
//    public void testLclAdjust() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.getItemInfo()));
//    public void testGetItemInfo() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.lclDelete()));
//    public void testLclDelete() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.pieceBreak()));
//    public void testPieceBreak() throws Exception {
//
//    }
//    @Test//System.out.println(JSON.toJSONString(InnerCheckController.innerCheckConfig()));
//    public void testInnerCheckConfig() throws Exception {
//
//    }
//
//}
